@@ -23,7 +23,7 @@ test_that("fails correctly", {
   skip_on_cran()
   
   vcr::use_cassette("enumeration_fails_well", {
-    expect_error(enumeration("asdfadsf"), "Status: 204 - not found")
+    expect_error(enumeration("asdfadsf"))
   })
 
   expect_error(enumeration_country(list(timeout_ms = 1)),
